EntityResult class

Constructors

EntityResult(String name, List<Field> fields, List<EntityResult> nested)
Creates a parsed entity result with fields and nested entities.

Properties

fields → List<Field>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
nested → List<EntityResult>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited