Field class

Constructors

Field(String name, String type, bool nullable)
Creates a field descriptor with type and nullability.

Properties

fullType → String
Returns the type string with nullability applied.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
nullable → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited