JsonToEntity class

JSON to Zorphy entity converter Infers types from JSON and generates Zorphy entities

Constructors

JsonToEntity({bool prefixNested = true})
Creates a converter that can prefix nested entity names.

Properties

hashCode → int
The hash code for this object.
no setterinherited
prefixNested → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(Map<String, dynamic> json, String name, {String? parentPrefix}) → EntityResult
Parses JSON into an entity definition tree.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited