EnumConfig class

Configuration for enum creation

Constructors

EnumConfig({required String name, String? outputDir, List<String> values = const [], bool dryRun = false})
const

Properties

className String
no setter
defaultOutputDir String
no setter
dryRun bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
outputDir String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snakeName String
no setter
values List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited