EnumResult class

Result of enum creation

Constructors

EnumResult({required String enumName, required String filePath, required String content, bool created = true, String? error})
const
EnumResult.failure(String? error)
const

Properties

content String
final
created bool
final
enumName String
final
error String?
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited