ValidationFinding class
A single validation finding.
Constructors
- ValidationFinding({required String message, required ValidationSeverity severity, String? filePath, int? lineNumber, String? fixSuggestion})
-
const
Properties
- filePath → String?
-
Absolute file path this finding relates to (if applicable).
final
- fixSuggestion → String?
-
Suggested fix or remediation step.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineNumber → int?
-
Line number in the file (if applicable).
final
- message → String
-
Human-readable description of the finding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → ValidationSeverity
-
Severity level.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited