ValidationResult class

Aggregated result of running all validation checks.

Constructors

ValidationResult({required List<ValidationFinding> findings, required String validatedDir, int filesScanned = 0})
const

Properties

errorCount int
no setter
filesScanned int
Number of files scanned.
final
findings List<ValidationFinding>
All findings from the validation run.
final
hasErrors bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasIssues bool
no setter
infoCount int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validatedDir String
The directory that was validated.
final
warningCount int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited