toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buf = StringBuffer();
  buf.writeln('Zorphy Validation Report');
  buf.writeln('Directory: $validatedDir');
  buf.writeln('Files scanned: $filesScanned');
  buf.writeln('');

  if (findings.isEmpty) {
    buf.writeln('No issues found.');
  } else {
    for (final f in findings) {
      buf.write(f);
    }
    buf.writeln('');
    buf.writeln('Summary: $errorCount error(s), $warningCount warning(s), $infoCount info');
  }
  return buf.toString();
}