ValidationSeverity enum

Severity levels for validation findings.

Inheritance
Available extensions

Values

none → const ValidationSeverity

No issues found.

info → const ValidationSeverity

A suggestion for improvement, not required.

warning → const ValidationSeverity

A potential issue that may cause problems.

error → const ValidationSeverity

A definite problem that will cause errors.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ValidationSeverity>
A constant List of the values in this enum, in order of their declaration.