EntityCreator class
Main orchestrator for creating Zorphy entities
Constructors
- EntityCreator({String? baseOutputDir})
Properties
- baseOutputDir → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addFields(
String entityName, List< FieldDefinition> newFields, {String? outputDir, bool dryRun = false}) → Future<EntityResult> - Add fields to an existing entity
-
create(
EntityConfig config) → Future< EntityResult> - Create an entity and return the result
-
createEnum(
EnumConfig config) → Future< EnumResult> - Create an enum and return the result
-
generateInlineSubtypes(
EntityConfig parentConfig, Map< String, List< subtypeFields) → Future<FieldDefinition> >List< SubtypeResult> > - Generate subtypes for a sealed class (inline in same file)
-
generateSubtypeFiles(
EntityConfig parentConfig, Map< String, List< subtypeFields) → Future<FieldDefinition> >List< EntityResult> > - Generate subtypes as separate files
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited