ProjectValidator class
Runs all validation checks against a project directory and returns an aggregated ValidationResult.
Constructors
-
ProjectValidator({required String projectDir, List<
String> ? sourceDirs})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectDir → String
-
Root directory of the Dart project to validate.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceDirs
→ List<
String> -
Glob pattern for source directories to scan (relative to projectDir).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → ValidationResult - Run all validation checks and return the result.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited