UpdateCheckResult class
Result of checking for a CLI update.
Constructors
Properties
- currentVersion → String
-
The version currently running (from the _version constant).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latestVersion → String?
-
The latest version available on pub.dev.
final
- message → String
-
Human-readable message describing the result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
HTTP status code from the pub.dev API call, or null if not applicable.
final
- updateAvailable → bool
-
Whether a newer version is available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited