UpdateResult class
Result of performing the self-update.
Constructors
- UpdateResult({required bool success, required String message, String? newVersion, int? exitCode})
-
const
Properties
- exitCode → int?
-
The exit code of the
dart pub global activateprocess.final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable message describing the outcome.
final
- newVersion → String?
-
The version after the update (if verifiable).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the update succeeded.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited